Gbulb was originally created by Anthony Baire in September 2013.
It was maintained by Nathan Hoad from 2015? until October 2021.

It is currently maintained by Russell Keith-Magee, as part of the BeeWare project.

And here is an inevitably incomplete list of MUCH-APPRECIATED CONTRIBUTORS --
people who have submitted patches, reported bugs, added translations, helped
answer newbie questions, and generally made gbulb that much better:

* Jan Lübbe
* Krzysztof Kotlenga
* montag451
* Brecht De Vlieger
